/*
 * File:    DemoApplet.java
 * Package: dm.vpi.lekce06.applet
 * Project: Lekce06
 * 
 * Author : David Martinek
 * Address: Department of Intelligent Systems
 *          Faculty of Information Technology
 *          Brno University of Technology
 *          Bozetechova 2, 
 *          612 66 Brno, 
 *          Czech Republic
 * E-mail : martinek@fit.vutbr.cz
 * 
 * Created on 19.4.2005
 * (c) 2005, David Martinek
 * 
 * This project is provided under conditions of GNU General Public Licence.
 * The full text of GNU GPL in on internet: http://www.gnu.org/licenses/gpl.html
 * 
 * $Id$
 */
package dm.vpi.lekce06.applet;

import java.applet.Applet;
import java.awt.Color;
import java.awt.Font;
import java.awt.Graphics;

/**
 * <p>
 * Ukázkový aplet - jednoduchý čítač.
 * </p>
 * <p>
 * Existují omezení, která je potřeba při vytváření apletů brát v úvahu. Ve
 * VM v prohlížeči běží <code>SecurityManager</code>, který nedovolí
 * činnosti, které by mohly způsobit bezpečnostní problémy. Pokud detekuje
 * problém, vyhodí výjimku <code>SecurityException</code>. Zejména
 * nelze:
 * </p>
 * <ul>
 * <li> číst některé systémové proměnné pomocí
 * <code>System.getProperty()</code> </li>
 * <li> otevírat nebo vytvářet soubory na počítači, na kterém aplet běží
 * </li>
 * <li> navazovat internetová spojení s jiným serverem, než na jakém se
 * fyzicky nachází kód apletu a podobně. </li>
 * <li>spouštět programy na hostitelském počítači. </li>
 * </ul>
 * 
 * @since 19.4.2005
 * @author David Martinek
 */
public class DemoApplet
    extends Applet
    implements Runnable
{
  /**
   * Comment for <code>serialVersionUID</code>
   */
  private static final long serialVersionUID = 3905527115888474417L;

  private Thread myThread;

  private int citac = 0;


  /**
   * <p>
   * Tato metoda provádí inicializaci apletu. U apletů tato metoda
   * nahrazuje konstruktor. Tuto metodu volá prohlížeč hned po natažení
   * apletu do paměti.
   * </p>
   * <p>
   * Tato metoda se typicky používá pro vytvoření uživatelského rozhraní
   * (tlačítka, grafické a textové boxy, atd.). V žádném případě nemá smysl
   * v této metodě něco vykreslovat. Od toho je metoda <code>paint()</code>.
   * </p>
   * 
   * @see java.applet.Applet#init()
   */
  public void init()
  {
    this.setBackground(Color.orange);
    Font f = new Font("SansSerif", Font.BOLD, 40);
    this.setFont(f);
  }

  /**
   * <p>
   * Prohlížeč tuto metodu zavolá pokaždé, když aplet získá zaměření, tj.
   * když se poprvé zobrazí, když dojde k obnovení minimalizovaného okna
   * prohlížeče, když se dostane prohlížeč do popředí, atd. Rozdíl oproti
   * metodě <code>init()</code> je v tom, že <code>init()</code> se
   * typicky zavolá jenom jednou za život apletu, ale metoda
   * <code>start()</code> se volá mnohem častěji.
   * </p>
   * 
   * @see java.applet.Applet#start()
   */
  public void start()
  {
    if (myThread == null)
    {
      myThread = new Thread(this);
    }
    myThread.start();
  }

  /**
   * Metoda z rozhraní Runnable, která reprezentuje vlastní tělo vlákna.
   */
  public void run()
  {
    Thread current = Thread.currentThread();
    current.setPriority(Thread.MIN_PRIORITY);

    while (current == myThread)
    {
      citac++;
      repaint();
      try
      {
        Thread.sleep(1000);
      }
      catch (InterruptedException e)
      {
        break;
      }
    }
  }

  /**
   * <p>
   * Zastavení apletu, když tento přestane být viditelný (je překryt jiným
   * oknem, je odrolován, prohlížeč byl minimalizován, atd.). Pokud jsou
   * aktivní nějaká vlákna, mohou tak zůstat i po zavolání této metody.
   * </p>
   * 
   * @see java.applet.Applet#stop()
   */
  public void stop()
  {
    myThread = null;
  }

  /**
   * <p>
   * Závěrečný úklid při uzavření stránky s apletem. Rozdíl oproti volání
   * metody <code>stop()</code> je v tom, že po zavolání destroy budou
   * ukončena všechna aktivní vlákna spolu s celou aplikací.
   * </p>
   * 
   * @see java.applet.Applet#destroy()
   */
  public void destroy()
  {

  }

  /**
   * Vykreslí grafické okno apletu. Tahle metoda se zavolá pokaždé, když je
   * potřeba aplet překreslit. Aplet sám by tuto metodu neměl volat. Pokud
   * je potřeba aplet překreslit, dělá se to zavoláním metody
   * <code>repaint()</code>.
   * 
   * @see java.awt.Container#paint(java.awt.Graphics)
   */
  public void paint(Graphics g)
  {
    g.drawRect(0, 0, getSize().width - 1, getSize().height - 1);
    g.drawString("" + citac, 5, 50);
  }

}

// end of file DemoApplet.java
